Installation
============

To use ``Ycleptic``, install it from PyPI:

.. code-block:: bash

   $ pip install ycleptic

If you want a bleeding-edge, potentially unstable version, or you just want the source code, you can clone it from GitHub:

.. code-block:: bash

   $ git clone https://github.com/cameronabrams/ycleptic.git

Of course, if you want to contribute to it, you should fork the repository first.  Commits tagged as releases are typically stable.  Consider pulling changes from the repository periodically to keep up with the latest development.